package Bundle::Locale::CLDR::Westernafrica;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Westernafrica

=head1 CONTENTS

Locale::CLDR::Locales::Ak 0.46.0

Locale::CLDR::Locales::Ar 0.46.0

Locale::CLDR::Locales::Bm 0.46.0

Locale::CLDR::Locales::Ee 0.46.0

Locale::CLDR::Locales::Ff 0.46.0

Locale::CLDR::Locales::Fr 0.46.0

Locale::CLDR::Locales::Ha 0.46.0

Locale::CLDR::Locales::Ig 0.46.0

Locale::CLDR::Locales::Pt 0.46.0

Locale::CLDR::Locales::Wo 0.46.0

Locale::CLDR::Locales::Yo 0.46.0

Locale::CLDR::Locales::Ann 0.46.0

Locale::CLDR::Locales::Blo 0.46.0

Locale::CLDR::Locales::Cch 0.46.0

Locale::CLDR::Locales::Dje 0.46.0

Locale::CLDR::Locales::Dyo 0.46.0

Locale::CLDR::Locales::Gaa 0.46.0

Locale::CLDR::Locales::Kaj 0.46.0

Locale::CLDR::Locales::Kcg 0.46.0

Locale::CLDR::Locales::Kea 0.46.0

Locale::CLDR::Locales::Khq 0.46.0

Locale::CLDR::Locales::Kpe 0.46.0

Locale::CLDR::Locales::Nqo 0.46.0

Locale::CLDR::Locales::Pcm 0.46.0

Locale::CLDR::Locales::Ses 0.46.0

Locale::CLDR::Locales::Twq 0.46.0

Locale::CLDR::Locales::Vai 0.46.0

Locale::CLDR::Locales::Ak::Latn 0.46.0

Locale::CLDR::Locales::Ar::Arab 0.46.0

Locale::CLDR::Locales::Bm::Latn 0.46.0

Locale::CLDR::Locales::Bm::Nkoo 0.46.0

Locale::CLDR::Locales::Ee::Latn 0.46.0

Locale::CLDR::Locales::Ff::Adlm 0.46.0

Locale::CLDR::Locales::Ff::Latn 0.46.0

Locale::CLDR::Locales::Fr::Latn 0.46.0

Locale::CLDR::Locales::Ha::Arab 0.46.0

Locale::CLDR::Locales::Ha::Latn 0.46.0

Locale::CLDR::Locales::Ig::Latn 0.46.0

Locale::CLDR::Locales::Pt::Latn 0.46.0

Locale::CLDR::Locales::Wo::Latn 0.46.0

Locale::CLDR::Locales::Yo::Latn 0.46.0

Locale::CLDR::Locales::Ann::Latn 0.46.0

Locale::CLDR::Locales::Blo::Latn 0.46.0

Locale::CLDR::Locales::Cch::Latn 0.46.0

Locale::CLDR::Locales::Dje::Latn 0.46.0

Locale::CLDR::Locales::Dyo::Latn 0.46.0

Locale::CLDR::Locales::Gaa::Latn 0.46.0

Locale::CLDR::Locales::Kaj::Latn 0.46.0

Locale::CLDR::Locales::Kcg::Latn 0.46.0

Locale::CLDR::Locales::Kea::Latn 0.46.0

Locale::CLDR::Locales::Khq::Latn 0.46.0

Locale::CLDR::Locales::Kpe::Latn 0.46.0

Locale::CLDR::Locales::Nqo::Nkoo 0.46.0

Locale::CLDR::Locales::Pcm::Latn 0.46.0

Locale::CLDR::Locales::Ses::Latn 0.46.0

Locale::CLDR::Locales::Twq::Latn 0.46.0

Locale::CLDR::Locales::Vai::Latn 0.46.0

Locale::CLDR::Locales::Vai::Vaii 0.46.0

Locale::CLDR::Locales::Ak::Latn::Gh 0.46.0

Locale::CLDR::Locales::Ar::Arab::Mr 0.46.0

Locale::CLDR::Locales::Bm::Latn::Ml 0.46.0

Locale::CLDR::Locales::Bm::Nkoo::Ml 0.46.0

Locale::CLDR::Locales::Ee::Latn::Gh 0.46.0

Locale::CLDR::Locales::Ee::Latn::Tg 0.46.0

Locale::CLDR::Locales::En::Latn::Gh 0.46.0

Locale::CLDR::Locales::En::Latn::Gm 0.46.0

Locale::CLDR::Locales::En::Latn::Lr 0.46.0

Locale::CLDR::Locales::En::Latn::Ng 0.46.0

Locale::CLDR::Locales::En::Latn::Sh 0.46.0

Locale::CLDR::Locales::En::Latn::Sl 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Bf 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gh 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gm 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gn 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Gw 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Lr 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Mr 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Ne 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Ng 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Sl 0.46.0

Locale::CLDR::Locales::Ff::Adlm::Sn 0.46.0

Locale::CLDR::Locales::Ff::Latn::Bf 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gh 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gm 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gn 0.46.0

Locale::CLDR::Locales::Ff::Latn::Gw 0.46.0

Locale::CLDR::Locales::Ff::Latn::Lr 0.46.0

Locale::CLDR::Locales::Ff::Latn::Mr 0.46.0

Locale::CLDR::Locales::Ff::Latn::Ne 0.46.0

Locale::CLDR::Locales::Ff::Latn::Ng 0.46.0

Locale::CLDR::Locales::Ff::Latn::Sl 0.46.0

Locale::CLDR::Locales::Ff::Latn::Sn 0.46.0

Locale::CLDR::Locales::Fr::Latn::Bf 0.46.0

Locale::CLDR::Locales::Fr::Latn::Bj 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ci 0.46.0

Locale::CLDR::Locales::Fr::Latn::Gn 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ml 0.46.0

Locale::CLDR::Locales::Fr::Latn::Mr 0.46.0

Locale::CLDR::Locales::Fr::Latn::Ne 0.46.0

Locale::CLDR::Locales::Fr::Latn::Sn 0.46.0

Locale::CLDR::Locales::Fr::Latn::Tg 0.46.0

Locale::CLDR::Locales::Ha::Arab::Ng 0.46.0

Locale::CLDR::Locales::Ha::Latn::Gh 0.46.0

Locale::CLDR::Locales::Ha::Latn::Ne 0.46.0

Locale::CLDR::Locales::Ha::Latn::Ng 0.46.0

Locale::CLDR::Locales::Ig::Latn::Ng 0.46.0

Locale::CLDR::Locales::Pt::Latn::Cv 0.46.0

Locale::CLDR::Locales::Pt::Latn::Gw 0.46.0

Locale::CLDR::Locales::Pt::Latn::Pt 0.46.0

Locale::CLDR::Locales::Wo::Latn::Sn 0.46.0

Locale::CLDR::Locales::Yo::Latn::Bj 0.46.0

Locale::CLDR::Locales::Yo::Latn::Ng 0.46.0

Locale::CLDR::Locales::Ann::Latn::Ng 0.46.0

Locale::CLDR::Locales::Blo::Latn::Bj 0.46.0

Locale::CLDR::Locales::Cch::Latn::Ng 0.46.0

Locale::CLDR::Locales::Dje::Latn::Ne 0.46.0

Locale::CLDR::Locales::Dyo::Latn::Sn 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0

Locale::CLDR::Locales::Gaa::Latn::Gh 0.46.0

Locale::CLDR::Locales::Kaj::Latn::Ng 0.46.0

Locale::CLDR::Locales::Kcg::Latn::Ng 0.46.0

Locale::CLDR::Locales::Kea::Latn::Cv 0.46.0

Locale::CLDR::Locales::Khq::Latn::Ml 0.46.0

Locale::CLDR::Locales::Kpe::Latn::Gn 0.46.0

Locale::CLDR::Locales::Kpe::Latn::Lr 0.46.0

Locale::CLDR::Locales::Nqo::Nkoo::Gn 0.46.0

Locale::CLDR::Locales::Pcm::Latn::Ng 0.46.0

Locale::CLDR::Locales::Ses::Latn::Ml 0.46.0

Locale::CLDR::Locales::Twq::Latn::Ne 0.46.0

Locale::CLDR::Locales::Vai::Latn::Lr 0.46.0

Locale::CLDR::Locales::Vai::Vaii::Lr 0.46.0


=cut

1;

